@@ -165,7 +165,7 @@
 	'id': 100,
 	'owner': false,
         'sentence': 'the game sentence',
-        'board': [30,31,32],
+        'board': [30,31,32,33],
         'winner_card': 30,
         'players': [ [ 'voter11', 30, 'y', 32, [ ] ],
                      [ 'voter12', null, 'y', 30, [ ] ],
@@ -179,7 +179,7 @@
 	'id': 100,
 	'owner': true,
         'sentence': 'the game sentence',
-        'board': [30,31,32],
+        'board': [30,31,32,33],
         'winner_card': 30,
         'players': [ [ 'voter11', 30, 'y', 32, [ ] ],
                      [ 'voter12', null, 'y', 30, [ ] ],
